@@ -94,13 +94,13 @@ async def test_fill_tentacle_config():
     available_tentacle = util.load_tentacle_with_metadata(constants.TENTACLES_PATH)
     with mock.patch.object(setup_config, "_get_installation_context_bot_version", mock.Mock()) as bot_version_mock:
         bot_version_mock.return_value = "1.0.5"
-        await setup_config.fill_tentacle_config(available_tentacle, constants.TENTACLE_CONFIG_FILE_NAME)
+        setup_config.fill_tentacle_config(available_tentacle, constants.TENTACLE_CONFIG_FILE_NAME)
         assert setup_config.installation_context == {
             constants.TENTACLE_INSTALLATION_CONTEXT_OCTOBOT_VERSION: "1.0.5"
         }
 
     setup_config = configuration.TentaclesSetupConfiguration()
-    await setup_config.fill_tentacle_config(available_tentacle, constants.TENTACLE_CONFIG_FILE_NAME)
+    setup_config.fill_tentacle_config(available_tentacle, constants.TENTACLE_CONFIG_FILE_NAME)
     assert setup_config.installation_context == {
         constants.TENTACLE_INSTALLATION_CONTEXT_OCTOBOT_VERSION:
             constants.TENTACLE_INSTALLATION_CONTEXT_OCTOBOT_VERSION_UNKNOWN
